@@ -861,6 +861,11 @@ def cmdnext(ui, repo, **opts):
                             if repo[rev].topic() != topic)
             aspchildren = [rev for rev in aspchildren if rev not in filtered]
 
+        # Let's make sure we don't have any duplicates between children and
+        # aspiring children
+        filtered.update(ctx.rev() for ctx in children)
+        aspchildren = [rev for rev in aspchildren if rev not in filtered]
+
         # To catch and prevent the case when `next` would get confused by split,
         # lets filter those aspiring children which can be stablized on one of
         # the aspiring children itself.
@@ -877,8 +882,7 @@ def cmdnext(ui, repo, **opts):
         if needevolve and opts['evolve']:
             hint = _(b'use `hg amend`, `hg revert` or `hg shelve`')
             cmdutil.bailifchanged(repo, hint=hint)
-
-        if not (opts['merge'] or (needevolve and opts['evolve'])):
+        elif not opts['merge']:
             # we only skip the check if noconflict is set
             if ui.config(b'commands', b'update.check') == b'noconflict':
                 pass
