@@ -579,7 +579,7 @@ def _createtempcommit(ui, repo, old, match):
         c.write(fp)
 
     fp.seek(0)
-    oldnode = node.hex(old.node())[:12]
+    oldnode = node.short(old.node())
     message = b'temporary commit for uncommiting %s' % oldnode
     tempnode = _patchtocommit(ui, repo, old, fp, message, oldnode)
     return tempnode
@@ -1484,7 +1484,7 @@ def abortpick(ui, repo, pickstate, abortcmd=False):
     pickstate.load()
     pctxnode = pickstate[b'oldpctx']
     ui.status(_(b"aborting pick, updating to %s\n") %
-              node.hex(pctxnode)[:12])
+              node.short(pctxnode))
     compat.clean_update(repo[pctxnode])
     pickstate.delete()
     return 0
