@@ -232,7 +232,7 @@ colortable = {b'topic.active': b'green',
               b'topic.active': b'green',
               }
 
-__version__ = b'0.22.1'
+__version__ = b'0.22.2'
 
 testedwith = b'4.6.2 4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8'
 minimumhgversion = b'4.6'
@@ -590,7 +590,9 @@ def reposetup(ui, repo):
 
             topicmodeserver = self.ui.config(b'experimental',
                                              b'topic-mode.server', b'ignore')
-            ispush = (desc.startswith(b'push') or desc.startswith(b'serve'))
+            publishbare = self.ui.configbool(b'experimental',
+                                             b'topic.publish-bare-branch')
+            ispush = desc.startswith((b'push', b'serve'))
             if (topicmodeserver != b'ignore' and ispush):
                 if util.safehasattr(tr, 'validator'): # hg <= 4.7 (ebbba3ba3f66)
                     origvalidator = tr.validator
@@ -616,10 +618,7 @@ def reposetup(ui, repo):
                 else:
                     tr.addvalidator(b'000-reject-untopiced', _validate)
 
-            elif (self.ui.configbool(b'experimental', b'topic.publish-bare-branch')
-                    and (desc.startswith(b'push')
-                         or desc.startswith(b'serve'))
-                    ):
+            elif publishbare and ispush:
                 origclose = tr.close
                 trref = weakref.ref(tr)
 
@@ -1059,6 +1058,14 @@ def _changetopics(ui, repo, revs, newtopic):
     for r in revs:
         c = repo[r]
 
+        if len(c.parents()) > 1:
+            # ctx.files() isn't reliable for merges, so fall back to the
+            # slower repo.status() method
+            st = c.p1().status(c)
+            files = set(st.modified) | set(st.added) | set(st.removed)
+        else:
+            files = set(c.files())
+
         def filectxfn(repo, ctx, path):
             try:
                 return c[path]
@@ -1097,7 +1104,7 @@ def _changetopics(ui, repo, revs, newtopic):
         mc = context.memctx(repo,
                             (p1, p2),
                             c.description(),
-                            c.files(),
+                            files,
                             filectxfn,
                             user=c.user(),
                             date=c.date(),
